#ifndef NT2_INCLUDE_FUNCTIONS_PROPER_TANPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PROPER_TANPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/proper_tanpi.hpp>

#endif
